﻿Theme: dict = {
    "Colors": {
        "base": "#004d99",
        "second": "#0066cc",
        "third": "#0080ff",
        "highlight": "#3399ff",
        "text": "white",
        "placeholder": "#cccccc",
        "textStyle": "black",
        "blank": "transparent",
        "success": "#00b300",
        "error": "#ff1a1a",
        "shadowError": "#99ff1a1a",
        "shadowBlack": "#99000000",
        "linkReady": "#b3b3ff"
    },

    "Margins": {
        "zero": 0,
        "tiny": 5,
        "small": 10,
        "normal": 15,
        "big": 20
    },

    "Visible": {
        "on": 1.0,
        "off": 0.0,
        "disabled": 0.4
    },

    "Size": {
        "border": 1,
        "borderBold": 2,
        "icon": 36,
        "iconSmall": 16,
        "none": 0
    },

    "Animation": {
        "hover": 50,
        "quick": 250,
        "medium": 500,
        "normal": 1000
    },

    "Time": {
        "repeat": 5000
    },

    "FontSize": {
        "groupBoxLabel": 8,
        "micro": 10,
        "tiny": 14,
        "small": 16,
        "normal": 18,
        "big": 22
    },

    "String": {
        "empty": ""
    },

    "Capacity": {
        "empty": 0
    }
}
